# Django IBAN

**A validated Django model field for [International Bank Account Numbers](https://en.wikipedia.org/wiki/International_Bank_Account_Number) (IBAN).**

**Author:** Ben Konrath

**License:** 3-clause BSD

[![build-status-image]][travis]

Pull requests happily accepted.

[build-status-image]: https://secure.travis-ci.org/benkonrath/django-iban.png?branch=master
[travis]: http://travis-ci.org/benkonrath/django-iban?branch=master